==> haskell-configurator-0.3.0.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-configurator.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator
version: 0.3.0.0
id: configurator-0.3.0.0-9lZyExiC1BPHV0H1xAvnbU
key: configurator-0.3.0.0-9lZyExiC1BPHV0H1xAvnbU
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: http://github.com/bos/configurator
synopsis: Configuration management
description:
    A configuration management library for programs and daemons.
    .
    Features include:
    .
    * Automatic, dynamic reloading in response to modifications to
    configuration files.
    .
    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).
    .
    * Subscription-based notification of changes to configuration
    properties.
    .
    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.
    .
    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.
category: Configuration, Data
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Configurator Data.Configurator.Types
hidden-modules: Data.Configurator.Instances
                Data.Configurator.Parser Data.Configurator.Types.Internal
abi: 787bf71842753895fef04c155f90b8d6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/configurator-0.3.0.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/configurator-0.3.0.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/configurator-0.3.0.0
hs-libraries: HSconfigurator-0.3.0.0-9lZyExiC1BPHV0H1xAvnbU
depends:
    attoparsec-0.13.1.0-6gEFbI8p8A3LThVdJgpVvH base-4.9.0.0
    bytestring-0.10.8.1 directory-1.2.6.2
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
haddock-interfaces: /usr/share/doc/haskell-configurator/html/configurator.haddock
haddock-html: /usr/share/doc/haskell-configurator/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configurator-0.3.0.0-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-configurator.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator
version: 0.3.0.0
id: configurator-0.3.0.0-GmFsPBeuQR8GjLkkhP1Y2d
key: configurator-0.3.0.0-GmFsPBeuQR8GjLkkhP1Y2d
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: http://github.com/bos/configurator
synopsis: Configuration management
description:
    A configuration management library for programs and daemons.
    .
    Features include:
    .
    * Automatic, dynamic reloading in response to modifications to
    configuration files.
    .
    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).
    .
    * Subscription-based notification of changes to configuration
    properties.
    .
    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.
    .
    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.
category: Configuration, Data
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Configurator Data.Configurator.Types
hidden-modules: Data.Configurator.Instances
                Data.Configurator.Parser Data.Configurator.Types.Internal
abi: 3f918823de5a00bda11224c5672f1aaa
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/configurator-0.3.0.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/configurator-0.3.0.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/configurator-0.3.0.0
hs-libraries: HSconfigurator-0.3.0.0-GmFsPBeuQR8GjLkkhP1Y2d
depends:
    attoparsec-0.13.1.0-4MHT8pBlPVm5gUqsk1oQRa base-4.9.0.0
    bytestring-0.10.8.1 directory-1.2.6.2
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
haddock-interfaces: /usr/share/doc/haskell-configurator/html/configurator.haddock
haddock-html: /usr/share/doc/haskell-configurator/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
